@@ -184,7 +184,8 @@ babl_extension_load (const char *path)
   init = dlsym (dl_handle, "init");
   if (!init)
     {
-      babl_log ("\n\tint babl_extension_init() function not found in extenstion '%s'", path);
+      babl_log ("\n\tint babl_extension_init() function not found in extension '%s'", path);
+      dlclose (dl_handle);
       return load_failed (babl);
     }
 
@@ -197,10 +198,12 @@ babl_extension_load (const char *path)
   if (init ())
     {
       babl_log ("babl_extension_init() in extension '%s' failed (return!=0)", path);
+      dlclose (dl_handle);
       return load_failed (babl);
     }
 
-  if (babl_db_insert (db, babl) == babl)
+  babl_db_insert (db, babl);
+  if (babl == babl_db_exist_by_name (db, path))
     {
       babl_set_extender (NULL);
       return babl;
@@ -270,10 +273,13 @@ expand_path (char *path)
 
   while (*src)
     {
+      char *home;
       switch (*src)
         {
           case '~':
-            dst = babl_strcat (dst, getenv ("HOME"));
+            home = getenv ("HOME");
+            if (NULL != home)
+              dst = babl_strcat (dst, home);
             break;
 
           default:
@@ -351,4 +357,4 @@ each_babl_extension_destroy (Babl *babl,
   return 0;  /* continue iterating */
 }
 
-BABL_CLASS_TEMPLATE (extension)
+BABL_CLASS (extension)
