@@ -27,7 +27,8 @@ static int
 each_babl_format_destroy (Babl *babl,
                           void *data)
 {
-  babl_free (babl->format.from);
+  if (babl->format.from_list)
+    babl_list_destroy (babl->format.from_list);
   babl_free (babl);
 
   return 0;  /* continue iterating */
@@ -45,24 +46,25 @@ format_new (const char     *name,
 {
   Babl *babl;
 
-  {
-    int i;
-    /* i is desintation position */
-    for (i = 0; i < model->components; i++)
-      {
-        int j;
-
-        for (j = 0; j < components; j++)
-          {
-            if (component[j] == model->component[i])
-              goto component_found;
-          }
-        babl_fatal ("matching source component for %s in model %s not found",
-                    model->component[i]->instance.name, model->instance.name);
-component_found:
-        ;
-      }
-  }
+  /* i is desintation position */
+  int i, j, component_found = 0;
+  for (i = 0; i < model->components; i++)
+    {
+      for (j = 0; j < components; j++)
+        {
+          if (component[j] == model->component[i])
+            {
+              component_found = 1;
+              break;
+            }
+        }
+      if (!component_found)
+        {
+          component_found = 0;
+          babl_fatal ("matching source component for %s in model %s not found",
+                      model->component[i]->instance.name, model->instance.name);
+        }
+    }
 
   /* allocate all memory in one chunk */
   babl = babl_malloc (sizeof (BablFormat) +
@@ -73,7 +75,7 @@ component_found:
                       sizeof (int) * (components) +
                       sizeof (int) * (components));
 
-  babl->format.from      = NULL;
+  babl->format.from_list = NULL;
   babl->format.component = (void *) (((char *) babl) + sizeof (BablFormat));
   babl->format.type      = (void *) (((char *) babl->format.component) + sizeof (BablComponent *) * (components));
   babl->format.sampling  = (void *) (((char *) babl->format.type) + sizeof (BablType *) * (components));
@@ -101,6 +103,7 @@ component_found:
   }
 
   babl->format.loss = -1.0;
+  babl->format.visited = 0;
   babl->format.image_template = NULL;
 
   return babl;
@@ -109,7 +112,7 @@ component_found:
 
 static char buf[512] = "";
 
-static const char *
+static char *
 create_name (BablModel      *model,
              int             components,
              BablComponent **component,
@@ -295,17 +298,28 @@ babl_format_new (void *first_arg,
 
   va_end (varg);
 
-  babl = format_new (name ? name : create_name (model, components, component, type),
+  if (!name)
+    name = create_name (model, components, component, type);
+
+  babl = babl_db_exist (db, id, name);
+  if (babl)
+    {
+      /* There is an instance already registered by the required id/name,
+       * returning the preexistent one instead.
+       */
+      return babl;
+    }
+
+  babl = format_new (name,
                      id,
                      planar, components, model,
                      component, sampling, type);
 
-  {
-    Babl *ret = babl_db_insert (db, babl);
-    if (ret != babl)
-      babl_free (babl);
-    return ret;
-  }
+  /* Since there is not an already registered instance by the required
+   * id/name, inserting newly created class into database.
+   */
+  babl_db_insert (db, babl);
+  return babl;
 }
 
 int
@@ -422,4 +436,4 @@ babl_format_loss (Babl *babl)
   return loss;
 }
 
-BABL_CLASS_TEMPLATE (format)
+BABL_CLASS (format)
