@@ -21,20 +21,20 @@
 #include <string.h>
 #include "babl-internal.h"
 
-static void *(*malloc_f)(size_t size) = malloc;
-static void  (*free_f)(void *ptr)     = free;
+static BablMallocFunc malloc_f = malloc;
+static BablFreeFunc   free_f   = free;
 
 static void *first_malloc_used = NULL;
 static void *first_free_used   = NULL;
 
 void
-babl_set_malloc (void *(*malloc_function)(size_t size))
+babl_set_malloc (BablMallocFunc malloc_function)
 {
   malloc_f = malloc_function;
 }
 
 void
-babl_set_free (void (*free_function)(void *ptr))
+babl_set_free (BablFreeFunc free_function)
 {
   free_f = free_function;
 }
@@ -47,9 +47,9 @@ typedef struct
   size_t size;
 } BablAllocInfo;
 
-#define OFFSET    (sizeof (BablAllocInfo))
-
-#define BAI(ptr)       ((BablAllocInfo *) (((char *) ptr) - OFFSET))
+#define BABL_ALIGN     16
+#define BABL_ALLOC     (sizeof (BablAllocInfo) + sizeof (void *))
+#define BAI(ptr)       ((BablAllocInfo *) *((void **) ptr - 1))
 #define IS_BAI(ptr)    (BAI (ptr)->signature == signature)
 
 /* runtime statistics: */
@@ -96,18 +96,23 @@ void *
 babl_malloc (size_t size)
 {
   char *ret;
+  int  offset;
 
   babl_assert (size);
 
   functions_sanity ();
-  ret = malloc_f (size + OFFSET);
+  ret = malloc_f (BABL_ALLOC + BABL_ALIGN + size);
   if (!ret)
     babl_fatal ("args=(%i): failed", size);
 
-  BAI (ret + OFFSET)->signature = signature;
-  BAI (ret + OFFSET)->size      = size;
+  offset = BABL_ALIGN - ((unsigned int) ret + BABL_ALLOC) % BABL_ALIGN;
+  ret = ret + BABL_ALLOC + offset;
+
+  *((void **) ret - 1) = ret - BABL_ALLOC - offset;
+  BAI (ret)->signature = signature;
+  BAI (ret)->size      = size;
   mallocs++;
-  return (void *) (ret + OFFSET);
+  return (void *) (ret);
 }
 
 /* Create a duplicate allocation of the same size, note
@@ -298,6 +303,9 @@ babl_strcat (char       *dest,
   int   src_len;
   int   dst_len;
 
+  if (NULL == src)
+    return dest;
+
   src_len = strlen (src);
   if (!dest)
     {
