@@ -28,7 +28,8 @@ static int
 each_babl_type_destroy (Babl *babl,
                         void *data)
 {
-  babl_free (babl->type.from);
+  if (babl->type.from_list)
+    babl_list_destroy (babl->type.from_list);
   babl_free (babl);
   return 0;  /* continue iterating */
 }
@@ -44,13 +45,13 @@ type_new (const char *name,
   babl_assert (bits != 0);
   babl_assert (bits % 8 == 0);
 
-  babl                = babl_malloc (sizeof (BablType) + strlen (name) + 1);
-  babl->instance.name = (void *) ((char *) babl + sizeof (BablType));
-  babl->class_type    = BABL_TYPE;
-  babl->instance.id   = id;
+  babl                 = babl_malloc (sizeof (BablType) + strlen (name) + 1);
+  babl->instance.name  = (void *) ((char *) babl + sizeof (BablType));
+  babl->class_type     = BABL_TYPE;
+  babl->instance.id    = id;
   strcpy (babl->instance.name, name);
-  babl->type.bits = bits;
-  babl->type.from = NULL;
+  babl->type.bits      = bits;
+  babl->type.from_list = NULL;
 
   return babl;
 }
@@ -128,21 +129,29 @@ babl_type_new (void *first_arg,
 
   va_end (varg);
 
+  babl = babl_db_exist (db, id, first_arg);
+  if (babl)
+    {
+      /* There is an instance already registered by the required id/name,
+       * returning the preexistent one instead.
+       */
+      return babl;
+    }
+
   babl = type_new (first_arg, id, bits);
 
-  {
-    Babl *ret = babl_db_insert (db, babl);
-    if (ret != babl)
-      babl_free (babl);
-    return ret;
-  }
+  /* Since there is not an already registered instance by the required
+   * id/name, inserting newly created class into database.
+   */
+  babl_db_insert (db, babl);
+  return babl;
 }
 
 
 #define TOLERANCE    0.000000001
 #define samples      512
 
-double test[samples];
+static double test[samples];
 
 static double r_interval (double min, double max)
 {
@@ -243,4 +252,4 @@ babl_type_is_symmetric (Babl *babl)
   return is_symmetrical;
 }
 
-BABL_CLASS_TEMPLATE (type)
+BABL_CLASS (type)
